@@ -32,7 +32,6 @@ mlmsplit <- function(x, index=NULL) {
 }
 
 
-
 #' Forecast a multiple linear model with possible time series components
 #'
 #' \code{forecast.mlm} is used to predict multiple linear models, especially
@@ -58,7 +57,7 @@ mlmsplit <- function(x, index=NULL) {
 #' interpreted as related to the subsequent time periods. If \code{FALSE}, any
 #' time series attributes of the original data will be ignored.
 #' @param ... Other arguments passed to \code{\link[forecast]{forecast.lm}()}.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #'
 #' @return An object of class "\code{mforecast}".
 #'
@@ -135,7 +134,7 @@ forecast.mlm <- function(object, newdata, h=10, level=c(80, 95), fan=FALSE, lamb
 #' multiplicative trends are allowed. Otherwise, only additive or no trend ETS
 #' models are permitted.
 #' @param ... Additional arguments affecting the forecasts produced.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #' @return An object of class "\code{mforecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -189,7 +188,6 @@ print.mforecast <- function(x, ...) {
 }
 
 
-
 #' Multivariate forecast plot
 #'
 #' Plots historical data with multivariate forecasts and prediction intervals.
@@ -248,15 +246,21 @@ plot.mforecast <- function(x, main=paste("Forecasts from", unique(x$method)), xl
 
 #' @export
 summary.mforecast <- function(object, ...) {
-  cat(paste("\nForecast method:", unique(object$method)))
+  class(object) <- c("summary.mforecast", class(object))
+  object
+}
+
+#' @export
+print.summary.mforecast <- function(x, ...) {
+  cat(paste("\nForecast method:", unique(x$method)))
   cat(paste("\n\nModel Information:\n"))
-  print(object$model)
+  print(x$model)
   cat("\nError measures:\n")
-  print(accuracy(object))
-  if (is.null(object$forecast)) {
+  print(accuracy(x))
+  if (is.null(x$forecast)) {
     cat("\n No forecasts\n")
   } else {
     cat("\nForecasts:\n")
-    print(object)
+    NextMethod()
   }
 }
