@@ -1,6 +1,5 @@
 # A unit test for spline.R
 if (require(testthat)) {
-  context("Testing splinef()")
   test_that("Tests for splinef()", {
     plot.splineforecast(splinef(airmiles))
     fit1 <- splinef(woolyrnq, lambda = 0.2, biasadj = FALSE)
@@ -8,7 +7,6 @@ if (require(testthat)) {
     expect_false(identical(fit1$mean, fit2$mean))
     splinef(woolyrnq, method = "mle")
     splinef(WWWusage, method = "mle")
-    expect_true(all(as.numeric(splinef(WWWusage, fan = TRUE)$mean) == as.numeric(splinef(WWWusage)$mean)))
     expect_error(splinef(woolyrnq, level = 110))
     expect_error(splinef(woolyrnq, level = -10))
   })
